@@ -1,6 +1,6 @@
 __package_name__ = 'portalocker'
 __author__ = 'Rick van Hattem'
 __email__ = 'wolph@wol.ph'
-__version__ = '2.8.1'
-__description__ = '''Wraps the portalocker recipe for easy usage'''
+__version__ = '3.1.1'
+__description__ = """Wraps the portalocker recipe for easy usage"""
 __url__ = 'https://github.com/WoLpH/portalocker'
